Crate ergo_nipopow

Crate ergo_nipopow 

Ergo NiPoPoW implementation See FC 20 (published) version https://fc20.ifca.ai/preproceedings/74.pdf

Structs

NipopowAlgos
A set of utilities for working with NiPoPoW protocol.
NipopowProof
A structure representing NiPoPow proof as a persistent modifier.
NipopowVerifier
A verifier for PoPoW proofs. During its lifetime, it processes many proofs with the aim of deducing at any given point what is the best (sub)chain rooted at the specified genesis.
PoPowHeader
PoPowHeader structure. Represents the block header and unpacked interlinks

Enums

NipopowProofError
NipopowProof errors

Constants

INTERLINK_VECTOR_PREFIX
Prefix for Block Interlinks

Functions

decode_compact_bits
The “compact” format is an encoding of a whole number N using an unsigned 32 bit number. This number encodes a base-256 scientific notation representation of N (similar to a floating point format):